summaryrefslogtreecommitdiff
path: root/Master
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2010-06-04 23:15:36 +0000
committerKarl Berry <karl@freefriends.org>2010-06-04 23:15:36 +0000
commitf8d95824f65118b8a2ab4b2873160733c523551b (patch)
treedda2cbb875025c5753b09487cf1c82937a4438ae /Master
parentc3a1d17a9ded47951c6be127d60ba32374f13384 (diff)
use "platform" throughout the doc in preference to "architecture".
git-svn-id: svn://tug.org/texlive/trunk@18743 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master')
-rwxr-xr-xMaster/texmf/scripts/texlive/tlmgr.pl45
1 files changed, 23 insertions, 22 deletions
diff --git a/Master/texmf/scripts/texlive/tlmgr.pl b/Master/texmf/scripts/texlive/tlmgr.pl
index 23e9f6c609f..966a1b6ab9d 100755
--- a/Master/texmf/scripts/texlive/tlmgr.pl
+++ b/Master/texmf/scripts/texlive/tlmgr.pl
@@ -999,7 +999,7 @@ sub action_show {
}
# in case we have them
if ($foo->allbinfiles) {
- print "bin files (all architectures):\n";
+ print "bin files (all platforms):\n";
for my $f (sort $foo->allbinfiles) { print " $f\n"; }
}
}
@@ -3039,12 +3039,12 @@ sub action_arch {
info("arch: dry run, no changes will be made\n") if $opts{"dry-run"};
$what || ($what = "list");
if ($what =~ m/^list$/i) {
# list the available architectures
# initialize the TLMedia from $location
init_tlmedia();
my $mediatlpdb = $tlmediasrc->tlpdb;
my @already_installed_arch = $localtlpdb->available_architectures;
- print "Available architectures:\n";
+ print "Available platforms:\n";
foreach my $a ($mediatlpdb->available_architectures) {
if (member($a,@already_installed_arch)) {
print "(i) $a\n";
@@ -3052,8 +3052,8 @@ sub action_arch {
print " $a\n";
}
}
- print "Already installed architectures are marked with (i)\n";
- print "You can add new architectures with tlmgr arch add arch1 arch2\n";
+ print "Already installed platforms are marked with (i)\n";
+ print "You can add new platforms with: tlmgr arch add ARCH1 ARCH2...\n";
finish(0);
} elsif ($what =~ m/^add$/i) {
return if !check_on_writable();
@@ -3440,12 +3440,12 @@ sub action_recreate_tlpdb {
if (member($opts{"arch"}, @archs)) {
push @deps, "setting_platform:" . $opts{"arch"};
} else {
- tlwarn("The architecture you passed in with --arch is not present in $Master/bin\n");
- tlwarn("Please specify one from the available ones: @archs\n");
+ tlwarn("The platform you passed in with --arch is not present in $Master/bin\n");
+ tlwarn("Please specify one of the available ones: @archs\n");
exit(1);
}
} else {
- tlwarn("More than one architecture available: @archs\n");
+ tlwarn("More than one platform available: @archs\n");
tlwarn("Please pass one as the default you are running on with --arch=...\n");
exit(1);
}
@@ -4897,7 +4897,7 @@ Exclude I<pkg> from the update process. If this option is given more
than once, its arguments accumulate.
An argument I<pkg> excludes both the package I<pkg> itself and all
-its related architecture-specific packages I<pkg.ARCH>. For example,
+its related platform-specific packages I<pkg.ARCH>. For example,
tlmgr update --all --exclude a2ping
@@ -5245,15 +5245,16 @@ those extra settings at present.
=head2 arch list|add|remove I<arch>...
-C<arch list> lists the TeX Live names of all the architectures
-(C<i386-linux>, ...) available at the package repository.
+C<arch list> lists the TeX Live names of all the platforms
+(a.k.a. architectures), (C<i386-linux>, ...) available at the package
+repository.
-C<arch add> I<arch>... adds the executables for each given architecture
-I<arch> to the installation.
+C<arch add> I<arch>... adds the executables for each given platform
+I<arch> to the installation from the repository.
C<arch remove> I<arch>... removes the executables for each given
-architecture I<arch> from the installation, but keeps the currently
-running architecture in any case.
+platform I<arch> from the installation, but keeps the currently
+running platform in any case.
Options:
@@ -5269,7 +5270,7 @@ written to the terminal.
=head2 print-arch
-Prints the currently detected architecture name to standard output.
+Prints the currently detected platform (architecture) name to standard output.
=head2 search [I<option>]... I<what>
@@ -5303,7 +5304,7 @@ date, version), but note that there is a high probability that this
information is slightly off due to timing issues.
If the option C<--list> is given with a package, the list of contained
-files is also shown, including those for architecture specific
+files is also shown, including those for platform-specific
dependencies. When given with schemes and collections, C<--list>
outputs their dependencies in a similar way.
@@ -5619,8 +5620,8 @@ Furthermore is allows to quit C<tlmgr>.
Provides access to three groups of options, I<General> (for almost all
options), I<Paper> (configuration of default paper sizes),
-I<Architectures> (only on Unix, configuration of the supported/installed
-architectures), as well as some toggles to turn on and off various
+I<Platforms> (only on Unix, configuration of the supported/installed
+platforms), as well as some toggles to turn on and off various
options.
There is also a toggle for C<Expert options> which defaults to on. If
@@ -5832,9 +5833,9 @@ each line are separated by a tab. Here are the fields.
=item I<pkgname>
-The TeX Live package identifier, with a possible architecture suffix for
-executables. For instance, C<pdftex> and C<pdftex.i386-linux> are
-given as two separate packages, one on each line.
+The TeX Live package identifier, with a possible platform suffix for
+executables. For instance, C<pdftex> and C<pdftex.i386-linux> are given
+as two separate packages, one on each line.
=item I<status>
@@ -3039,12 +3039,12 @@ sub action_arch {
$what || ($what = "list");
if ($what =~ m/^list$/i) {
- # list the available architectures
+ # list the available platforms
# initialize the TLMedia from $location
init_tlmedia();